from django.db import models
import datetime

class Issue(models.Model):
  name = models.CharField(max_length=255)
  date = models.DateField()
  published = models.BooleanField(default=False)
  notes = models.TextField(blank=True)

  def __unicode__(self):
    return self.name
  
class Article(models.Model):
  author = models.ForeignKey("Contributor", blank=True, null=True)
  title = models.CharField(max_length=255)
  notes = models.TextField(blank=True)
  issue = models.ForeignKey(Issue)

  def __unicode__(self):
    return self.title + " - " + self.author

class Contributor(models.Model):
  name = models.CharField(max_length=255)
  email = models.EmailField(blank=True, null=True)

  def __unicode__(self):
    return self.name + ": " + self.email

class Document(models.Model):
  file = models.FileField(upload_to='erang/documents/')
  title = models.CharField(max_length=500)
  issue = models.ForeignKey(Issue)
  notes = models.TextField(blank=True)
  contributor = models.ForeignKey(Contributor)
  doc_txt = models.TextField(blank=True)
  date_added = models.DateTimeField(default=datetime.datetime.now())
      
  def __unicode__(self):
    return self.title

class Image(models.Model):
  file = models.FileField(upload_to='erang/images/')
  title = models.CharField(max_length=255)
  issue = models.ForeignKey(Issue)
  notes = models.TextField(blank=True)
  date_added = models.DateTimeField(default=datetime.datetime.now())

  def __unicode__(self):
    return self.title


